==> cscec5b-rmat-api-3.0.1-20221027.035229-31-sources.jar: com/ejianc/business/rmat/vo/ExitSupplierVO.java <==
package com.ejianc.business.rmat.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 退场劳务队明细
 * 
 * @author generator
 * 
 */
public class ExitSupplierVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long exitId; // 退场主键ID
    private Long materialId; // 物资主键
    private String materialSourceId; // 物资来源主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String spec; // 规格型号
    private String memo; // 备注
    private String rentUnitId; // 计租单位id
    private String rentUnitName; // 计租单位
    private String unitId; // 档案单位id
    private String unitName; // 档案单位
    private String realUnitId; // 实物单位id
    private String realUnitName; // 实物单位
    private BigDecimal num; // 档案数量
    private BigDecimal rentNum; // 计租数量
    private BigDecimal realNum; // 实物数量
    private BigDecimal rentTransScale; // 计租转换系数
    private BigDecimal realTransScale; // 实物转换系数
    private BigDecimal rentOutNum; // 计租退场数量
    private BigDecimal realOutNum; // 实物退场数量
    private Long supplierId; // 设备供应商
    private String supplierName; // 供应商名称
    private String supplierSourceId; // 供应商来源ID
    

    public Long getExitId() {
        return exitId;
    }

    public void setExitId(Long exitId) {
        this.exitId = exitId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }
    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }
    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }
    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }
    public BigDecimal getRentOutNum() {
        return rentOutNum;
    }

    public void setRentOutNum(BigDecimal rentOutNum) {
        this.rentOutNum = rentOutNum;
    }
    public BigDecimal getRealOutNum() {
        return realOutNum;
    }

    public void setRealOutNum(BigDecimal realOutNum) {
        this.realOutNum = realOutNum;
    }

    @ReferSerialTransfer(referCode="support-supplier")
    public Long getSupplierId() {
        return supplierId;
    }

    @ReferDeserialTransfer
    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getSupplierSourceId() {
        return supplierSourceId;
    }

    public void setSupplierSourceId(String supplierSourceId) {
        this.supplierSourceId = supplierSourceId;
    }
    
}

==> cscec5b-rmat-api-3.0.1-20250120.044216-341-sources.jar: com/ejianc/business/rmat/vo/ExitSupplierVO.java <==
package com.ejianc.business.rmat.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 退场劳务队明细
 * 
 * @author generator
 * 
 */
public class ExitSupplierVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long exitId; // 退场主键ID
    private Long exitDetailId; // 退场明细主键ID
    private Long materialId; // 物资主键
    private String materialSourceId; // 物资来源主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String spec; // 规格型号
    private String memo; // 备注
    private String rentUnitId; // 计租单位id
    private String rentUnitName; // 计租单位
    private String unitId; // 档案单位id
    private String unitName; // 档案单位
    private String realUnitId; // 实物单位id
    private String realUnitName; // 实物单位
    private BigDecimal num; // 档案数量
    private BigDecimal rentNum; // 计租数量
    private BigDecimal realNum; // 实物数量
    private BigDecimal rentTransScale; // 计租转换系数
    private BigDecimal realTransScale; // 实物转换系数
    private BigDecimal rentOutNum; // 计租退场数量
    private BigDecimal realOutNum; // 实物退场数量
    private Long supplierId; // 设备供应商
    private String supplierName; // 供应商名称
    private String supplierSourceId; // 供应商来源ID
    private BigDecimal rentRecordOutNum; // 计租退场档案数量

    public Long getExitId() {
        return exitId;
    }

    public void setExitId(Long exitId) {
        this.exitId = exitId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }
    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }
    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }
    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }
    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }
    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }
    public BigDecimal getRentOutNum() {
        return rentOutNum;
    }

    public void setRentOutNum(BigDecimal rentOutNum) {
        this.rentOutNum = rentOutNum;
    }
    public BigDecimal getRealOutNum() {
        return realOutNum;
    }

    public void setRealOutNum(BigDecimal realOutNum) {
        this.realOutNum = realOutNum;
    }

    @ReferSerialTransfer(referCode="support-supplier")
    public Long getSupplierId() {
        return supplierId;
    }

    @ReferDeserialTransfer
    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getSupplierSourceId() {
        return supplierSourceId;
    }

    public void setSupplierSourceId(String supplierSourceId) {
        this.supplierSourceId = supplierSourceId;
    }

    public Long getExitDetailId() {
        return exitDetailId;
    }

    public void setExitDetailId(Long exitDetailId) {
        this.exitDetailId = exitDetailId;
    }

    public BigDecimal getRentRecordOutNum() {
        return rentRecordOutNum;
    }

    public void setRentRecordOutNum(BigDecimal rentRecordOutNum) {
        this.rentRecordOutNum = rentRecordOutNum;
    }
}
